
% Tool to get the indices and bulk download sealevel data for SCHISM coastal data points from
% http://sealevelx.ems.uwa.edu.au website using MATLAB
% yasha hetzel march 2019
% more info at: % http://sealevelx.ems.uwa.edu.au

% requirements: 
% 1) 'AUSTRALIA_2km_SCHISM_points.csv' defines all coastal point lat/lons
% and their IDs (available in FAQ on website)
% 2)  must define bounding box coordinates OR have Google earth kml polygon file available
% 
% example url: 
% 'http://sealevelx.ems.uwa.edu.au/data/00001_Data.nc'

%%     settings

% output directory to save nc files and location list
% whereput='Gracetown';
whereput='3mile';

% [OPTION 1] use bounding box to define boundaries
use_polygon=0 % this must be set to zero to use bounding box
ul=[-14.6887931258, 128.119250519] % upper left coordinates
lr= [-15.1594924268, 128.763642031] % lower right coordinates



% [OPTION 2] use google earth kml polygon to define boundaries
use_polygon=1 % this must be set to 1 to use polygon
polyname='3mile.kml' %'gracetown.kml' % this is the google earth polygon kml file


%% read the point info from text file
mkdir(whereput)
dat=csvread('AUSTRALIA_2km_SCHISM_points.csv',1,0);

ID=dat(:,1);
X=dat(:,2);
Y=dat(:,3);

% find points in polygon based on google earth polygon 
if use_polygon==1 %exist('polyname','var')
    clear inds
    % [lon lat]=readKMLpolygon('NT.kml');
    disp('finding all points using google earth polygon')
    
    [XV YV]=readKMLpolygon(polyname);
    
%     IN = inpolygon(mlon,mlat,lon,lat);
IN = inpolygon(X,Y,XV,YV);
%     inds=find(IN>0);
    
id=ID(IN);
x=X(IN);
y=Y(IN);

data_subset=table(id,x,y);
writetable(data_subset,[whereput filesep whereput '_SCHISM_points.csv']) ;

%% find points in polygon using box corners
% X=128.373183161;
% Y=-14.8119093171;

% % whereput='Cambridge_Gulf';
% % mkdir(whereput)
% 
% % use bounding box
% ul=[-14.6887931258, 128.119250519]
% lr= [-15.1594924268, 128.763642031]

elseif use_polygon==0
    disp('finding all points within bounding box')
    
XV=[ul(2) lr(2) lr(2) ul(2) ul(2)]
YV=[ul(1) ul(1) lr(1) lr(1) ul(1)]

IN = inpolygon(X,Y,XV,YV);

id=ID(IN);
x=X(IN);
y=Y(IN);

data_subset=table(id,x,y);
% save subset list of ID lat/lon 
writetable(data_subset,[whereput filesep whereput '_SCHISM_points.csv']) ;
end


%% get the data through the public url
% example url:
% http://sealevelx.ems.uwa.edu.au/data/24819_Data.nc

for i=1:length(id)

fname=[sprintf('%05d',id(i)) '_Data.nc'];
url=['http://sealevelx.ems.uwa.edu.au/data/' fname]
filename=[whereput filesep fname];
outfilename=websave(filename,url)
end

disp([' Downloaded data saved ' whereput ' for locations described in : ' whereput filesep whereput '_SCHISM_points.csv']);

%% junk
% 
% load('coastal_subset/final_2km_yh.mat')
% ID=[1:length(final_2km.x)]';
% X=final_2km.x';
% Y=final_2km.y';
% %% plot on  a map
% mli=14258:31479;
% isi=1:14257;
% tasi=1:1687;
% 
% 
% 
% figure; plot(final_2km.x(mli),final_2km.y(mli),'b.'); 
% hold on; plot(final_2km.x(isi),final_2km.y(isi),'r.');
% plot(final_2km.x(tasi),final_2km.y(tasi),'g.');
% legend('mainland 14258:31479','islands 1:14257','Tasmania 1:1687')
% %%
% 
% % organise points list and save to text
% 
% data=table(ID,X,Y);
% writetable(data,[whereput '/AUSTRALIA_2km_SCHISM_points.csv']) ;
